@@ -14,7 +14,7 @@ use File::Copy qw(copy);
 use File::Path qw(mkpath rmtree);
 use B qw(perlstring);
 
-our $VERSION = '0.010004'; # 0.10.4
+our $VERSION = '0.010005'; # 0.10.5
 
 $VERSION = eval $VERSION;
 
@@ -278,15 +278,17 @@ sub fatpack_end {
 
     if ($] < 5.008) {
       *{"${class}::INC"} = sub {
-         if (my $fat = $_[0]{$_[1]}) {
-           return sub {
-             return 0 unless length $fat;
-             $fat =~ s/^([^\n]*\n?)//;
-             $_ = $1;
-             return 1;
-           };
-         }
-         return;
+        if (my $fat = $_[0]{$_[1]}) {
+          my $pos = 0;
+          my $last = length $fat;
+          return (sub {
+            return 0 if $pos == $last;
+            my $next = (1 + index $fat, "\n", $pos) || $last;
+            $_ .= substr $fat, $pos, $next - $pos;
+            $pos = $next;
+            return 1;
+          });
+        }
       };
     }
 
@@ -347,8 +349,10 @@ L<article for Perl Advent 2012|http://www.perladvent.org/2012/2012-12-14.html>
 
 =head1 SUPPORT
 
-Your current best avenue is to come annoy mst on #toolchain on
-irc.perl.org. There should be a non-IRC means of support by 1.0.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-FatPacker>
+(or L<bug-App-FatPacker@rt.cpan.org|mailto:bug-App-FatPacker@rt.cpan.org>).
+
+You can normally also obtain assistance on irc, in #toolchain on irc.perl.org.
 
 =head1 AUTHOR
 
